#ifndef OPT_STATUS_H
#define OPT_STATUS_H

#include "optionstab.h"

class OptionsTabStatus : public MetaOptionsTab {
    Q_OBJECT
public:
    OptionsTabStatus(QObject *parent);
};

#endif // OPT_STATUS_H
